@@ -101,7 +101,7 @@ def add_random_synonymous_to_sentence(phrase, placeholder, synonyms):
     return phrase
 
 
-def data2nl(df):
+def data2nl(df, base_sentence=None):
     # The parameter "df" is a dataframe, but it will be converted into a dict, and called df in each case
 
     if not df.empty:
@@ -111,31 +111,35 @@ def data2nl(df):
         headers = {
             "Content-Type": "application/json"
         }
+        dict_df = df.to_dict(orient='records')
 
-        for i, row in df.iterrows():
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            data = {
-                "data": str(row)
-            }
+        url = url_list['BASE_URL_DATA2NL_DEV'] + "/data2nl"
 
-            s = requests.Session()
-            s.keep_alive = False
-            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-            s.mount('https://', HTTPAdapter(max_retries=retries))
+        for el in dict_df:
 
-            url = url_list['BASE_URL_DATA2NL_DEV'] + "/data2nl"
+            row = "Data: " + str(el)
+
+            if base_sentence is not None:
+                row = "BaseString: " + base_sentence + "\n" + row
+
+            data = {"data": row}
 
             r = s.post(url=url, headers=headers, json=data)
             r.raise_for_status()
 
             try:
                 nl = r.json()['nl']
-                row['nl'] = nl
+                el['nl'] = nl
             except Exception as e:
                 logging.error(str(e))
-                row['generated_nl'] = ""
+                el['generated_nl'] = ""
             tmp_df = pd.DataFrame()
-            tmp_df = tmp_df.append(row)
+            tmp_df = tmp_df.append(el, ignore_index=True)
             response_df = pd.concat([response_df, tmp_df], ignore_index=True, axis=0)
         return response_df
     else:
