@@ -111,10 +111,10 @@ class Insight_Definition:
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
-            if(multiple):
+            if (multiple):
                 self.edit_widget_multiple(widget_id, widget_type, query_ids, settings, values, texts, charts)
             else:
-                self.edit_widget(widget_id, widget_type,query_ids, settings, values, texts, charts)
+                self.edit_widget(widget_id, widget_type, query_ids, settings, values, texts, charts)
         return widget_id
 
     def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
@@ -173,11 +173,11 @@ class Insight_Definition:
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
-    def add_widget_test(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
+    def add_widget_test(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple= False):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
-            self.edit_widget_test(widget_id, widget_type,query_ids, settings, values, texts, charts)
+            self.edit_widget_multiple(widget_id, widget_type,query_ids, settings, values, texts, charts)
         return widget_id
 
     def edit_widget_multiple(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
@@ -214,8 +214,7 @@ class Insight_Definition:
                                continue
                         else:
                             ids.append(column["id"])
-
-            if(len(ids)>1):
+            if (len(ids) > 1):
                 settings[field + "_id"] = ids
             else:
                 settings[field + "_id"] = ids[0]
