@@ -146,6 +146,10 @@ class Condition:
 
     def __repr__(self):
         vars = []
+        if self.negate is not None:
+            negation = "NOT"
+        else:
+            negation = None
         if self.value is not None:
             for var in self.value:
                 vars.append(str(var))
@@ -172,34 +176,62 @@ class Condition:
             field_with_agg = self.field.complexExpression
 
         if formatted_value is not None and self.direction is None:
-            where_condition = (
-                    field_with_agg + " " + operator + " " + str(formatted_value)
-            )
+            if negation is None:
+                where_condition = (
+                        field_with_agg + " " + operator + " " + str(formatted_value)
+                )
+            else:
+                where_condition = (
+                    field_with_agg + " " + negation + " " + operator + " " + str(formatted_value)
+                )
         elif formatted_value is None and self.direction is not None:
             if isinstance(self.direction, PeriodOperator):
                 direction = self.direction.name
             else:
                 direction = self.direction
-            if self.steps is not None and self.interval is not None:
+            if negation is None:
+                if self.steps is not None and self.interval is not None:
+                    where_condition = (
+                            field_with_agg + " " + operator + " " + self.interval + " " + direction + " " + self.steps
+                    )
+                elif self.steps is not None and self.interval is None:
+                    where_condition = (
+                            field_with_agg + " " + operator + " " + direction + " " + self.steps
+                    )
+                elif self.steps is None and self.interval is not None:
+                    where_condition = (
+                            field_with_agg + " " + operator + " " + self.interval + " " + direction
+                    )
+                else:
+                    where_condition = (
+                            field_with_agg + " " + operator + " " + direction
+                    )
+            else:
+                if self.steps is not None and self.interval is not None:
+                    where_condition = (
+                            field_with_agg + " " + negation + " " + operator + " " + self.interval + " " + direction + " " + self.steps
+                    )
+                elif self.steps is not None and self.interval is None:
+                    where_condition = (
+                            field_with_agg + " " + negation + " " + operator + " " + direction + " " + self.steps
+                    )
+                elif self.steps is None and self.interval is not None:
+                    where_condition = (
+                            field_with_agg + " " + negation + " " + operator + " " + self.interval + " " + direction
+                    )
+                else:
+                    where_condition = (
+                            field_with_agg + " " + negation + " " + operator + " " + direction
+                    )
+        elif operator is not None:
+            if negation is None:
                 where_condition = (
-                        field_with_agg + " " + operator + " " + self.interval + " " + direction + " " + self.steps
-                )
-            elif self.steps is not None and self.interval is None:
-                where_condition = (
-                        field_with_agg + " " + operator + " " + direction + " " + self.steps
-                )
-            elif self.steps is None and self.interval is not None:
-                where_condition = (
-                        field_with_agg + " " + operator + " " + self.interval + " " + direction
+                        field_with_agg + " " + operator
                 )
             else:
                 where_condition = (
-                        field_with_agg + " " + operator + " " + direction
+                    field_with_agg + " " + negation + " " + operator
                 )
-        elif operator is not None:
-            where_condition = (
-                    field_with_agg + " " + operator
-            )
         else:
             where_condition = (
                 field_with_agg
@@ -298,7 +330,7 @@ class Query:
         fields_with_agg = [str(field) for field in self.fields]
         formatted_fields = ", ".join(fields_with_agg)
 
-        if self.datasets is not None:
+        if self.datasets is not None and self.datasets:
             froms_array = [d.dataset for d in self.datasets]
             table = ", ".join(froms_array)
         elif dataset is not None:
